@@ -39,13 +39,13 @@ class BTSmartHub(object):
         else:
             self.router_ip = DEFAULT_IP
 
+        self.referer = "http://{}/basic_-_my_devices.htm".format(self.router_ip)
+
         if not smarthub_model:
             self.smarthub_model = self.autodetect_smarthub_model()
         else:
             self.smarthub_model = smarthub_model
 
-        self.referer = "http://{}/basic_-_my_devices.htm".format(self.router_ip)
-
     def get_devicelist(self, only_active_devices=None,include_connections=None):
 
         if only_active_devices is None:
@@ -229,8 +229,6 @@ class BTSmartHub(object):
             return
         if response.status_code == 200:
             body = response.content.decode('utf-8')
-            # body strings are URI encoded
-            body = requests.utils.unquote(body)
         else:
             _LOGGER.error("Invalid response from Smart Hub: %s", response)
             _LOGGER.debug("It is likely that %s is the wrong router model", str(self.smarthub_model))
@@ -263,23 +261,17 @@ class BTSmartHub(object):
 
         # json likes double not single quotes
         cleaned_jscript_array = initial_jscript_array.replace("'", "\"")
+        cleaned_jscript_array = requests.utils.unquote(cleaned_jscript_array)
 
         return cleaned_jscript_array
 
-    def get_stations(self, owl_body=None):
+    def get_stations(self, owl_body):
         """
         Get the dict of stations (devices connected and info pertaining to how they connect)
         :param owl_body: The contents of the owl url - if not set we will look it up.
         :return: dictionary of stations mac -> station info.
         """
 
-        if owl_body is None:
-            # load the disks and stations...so we can enrich data.
-            request_url = 'http://' + self.router_ip + '/cgi/cgi_owl.js'
-            # use common method to pull body data for our url
-            owl_body = self.get_body_content(request_url)
-
-
         # labels in the extensions jscript
         extension_labels = [
             "station_mac", "station_name", "alias_name", "station_ip",
@@ -308,7 +300,7 @@ class BTSmartHub(object):
         return station_dictionary
 
 
-    def get_disks(self, owl_body=None):
+    def get_disks(self, owl_body):
         """
         Get the set of disks (extenders) and the info on the router.
         Used to figure out who is connected to what.
@@ -316,13 +308,6 @@ class BTSmartHub(object):
         :return: dict of mac address -> extender name.
         """
 
-        if owl_body is None:
-            # load the disks and stations...so we can enrich data.
-            request_url = 'http://' + self.router_ip + '/cgi/cgi_owl.js'
-            # use common method to pull body data for our url
-            owl_body = self.get_body_content(request_url, headers={'Referer': self.referer})
-
-
         # labels in the extensions jscript
         extension_labels = [
             "ordering", "hw_ver", "sw_ver",
@@ -432,16 +417,17 @@ class BTSmartHub(object):
                 device['ParentName'] = parent_name
 
         # shrink them down
-        if only_active_devices is False:
-            return self.parse_devicelist(devices)
-        else:
+        devices = self.parse_devicelist(devices)
+        if only_active_devices is True:
             return [device for device in devices if device.get('Active')]
 
+        return devices
+
     @staticmethod
     def parse_devicelist(device_list):
         """Returns relevant keys for devices in the router memory"""
 
-        keys = {'UserHostName', 'PhysAddress', 'IPAddress', 'Active',
+        keys = {'name', 'UserHostName', 'PhysAddress', 'IPAddress', 'Active',
                 'ConnectionType', 'ParentPhysAddress', 'ParentName'}
 
         # keys = {'UserHostName', 'PhysAddress', 'IPAddress', 'Active'}
@@ -467,7 +453,7 @@ class BTSmartHub(object):
         # First try to determine if router is Smarthub 2
         try:
             request_url = 'http://' + self.router_ip + '/cgi/cgi_basicMyDevice.js'
-            response = requests.get(request_url, timeout=wait_time)
+            response = requests.get(request_url, timeout=wait_time, headers={'Referer': self.referer})
             response.raise_for_status()
             if response.status_code == 200:
                 _LOGGER.info("Router (%s) appears to be a Smart Hub 2 ", self.router_ip)
